@@ -10,17 +10,38 @@ CONV_KERNEL_INITIALIZER = keras.initializers.VarianceScaling(scale=2.0, mode="fa
 # CONV_KERNEL_INITIALIZER = 'glorot_uniform'
 
 
-@tf.keras.utils.register_keras_serializable(package="common")
+@tf.keras.utils.register_keras_serializable(package="kecamCommon")
 def hard_swish(inputs):
     """ `out = xx * relu6(xx + 3) / 6`, arxiv: https://arxiv.org/abs/1905.02244 """
     return inputs * tf.nn.relu6(inputs + 3) / 6
 
 
+@tf.keras.utils.register_keras_serializable(package="kecamCommon")
+def mish(inputs):
+    """Mish: A Self Regularized Non-Monotonic Neural Activation Function.
+    Paper: [Mish: A Self Regularized Non-Monotonic Neural Activation Function](https://arxiv.org/abs/1908.08681)
+    Copied from https://github.com/tensorflow/addons/blob/master/tensorflow_addons/activations/mish.py
+    """
+    return inputs * tf.math.tanh(tf.math.softplus(inputs))
+
+
+@tf.keras.utils.register_keras_serializable(package="kecamCommon")
+def phish(inputs):
+    """Phish is defined as f(x) = xTanH(GELU(x)) with no discontinuities in the f(x) derivative.
+    Paper: https://www.techrxiv.org/articles/preprint/Phish_A_Novel_Hyper-Optimizable_Activation_Function/17283824
+    """
+    return inputs * tf.math.tanh(tf.nn.gelu(inputs))
+
+
 def activation_by_name(inputs, activation="relu", name=None):
     """ Typical Activation layer added hard_swish and prelu. """
     layer_name = name and activation and name + activation
     if activation == "hard_swish":
         return keras.layers.Activation(activation=hard_swish, name=layer_name)(inputs)
+    elif activation == "mish":
+        return keras.layers.Activation(activation=mish, name=layer_name)(inputs)
+    elif activation == "phish":
+        return keras.layers.Activation(activation=phish, name=layer_name)(inputs)
     elif activation.lower() == "prelu":
         shared_axes = list(range(1, len(inputs.shape)))
         shared_axes.pop(-1 if K.image_data_format() == "channels_last" else 0)
@@ -362,3 +383,36 @@ class CompatibleExtractPatches(keras.layers.Layer):
             }
         )
         return base_config
+
+
+class PreprocessInput:
+    """ `rescale_mode` `torch` means `(image - [0.485, 0.456, 0.406]) / [0.229, 0.224, 0.225]`, `tf` means `(image - 0.5) / 0.5` """
+
+    def __init__(self, input_shape=(224, 224, 3), rescale_mode="torch"):
+        self.rescale_mode = rescale_mode
+        self.input_shape = input_shape[1:-1] if len(input_shape) == 4 else input_shape[:2]
+
+    def __call__(self, image, resize_method="bilinear"):
+        image = tf.convert_to_tensor(image)
+        if tf.reduce_max(image) < 2:
+            image *= 255
+        image = tf.image.resize(image, self.input_shape, method=resize_method)
+        if len(image.shape) == 3:
+            image = tf.expand_dims(image, 0)
+
+        if self.rescale_mode == "raw":
+            return image
+        else:
+            return tf.keras.applications.imagenet_utils.preprocess_input(image, mode=self.rescale_mode)
+
+
+def decode_predictions(preds, top=5):
+    preds = preds.numpy() if isinstance(preds, tf.Tensor) else preds
+    return tf.keras.applications.imagenet_utils.decode_predictions(preds, top=5)
+
+
+def add_pre_post_process(model, rescale_mode="tf", input_shape=None):
+    input_shape = model.input_shape[1:-1] if input_shape is None else input_shape
+    model.preprocess_input = PreprocessInput(input_shape, rescale_mode=rescale_mode)
+    model.decode_predictions = decode_predictions
+    model.rescale_mode = rescale_mode
