@@ -109,7 +109,9 @@ def EfficientNetV2(
     first_conv_filter = blocks_config.get("first_conv_filter", out_channels[0])
     output_conv_filter = blocks_config.get("output_conv_filter", 1280)
     kernel_sizes = blocks_config.get("kernel_sizes", [3] * len(depthes))
-    rescale_mode = blocks_config.get("rescale_mode", "tf")
+    # "torch" for all V1 models
+    # for V2 models, "21k" pretrained are all "tf", "imagenet" pretrained "bx" models are all "torch", ["s", "m", "l", "xl"] are "tf"
+    rescale_mode = "tf" if pretrained is not None and pretrained.startswith("imagenet21k") else blocks_config.get("rescale_mode", "torch")
 
     inputs = keras.layers.Input(shape=input_shape)
     bn_eps = TORCH_BATCH_NORM_EPSILON if is_torch_mode else TF_BATCH_NORM_EPSILON
