@@ -16,7 +16,7 @@ def __gradient_ascent_step__(feature_extractor, image_var, filter_index, optimiz
     # Normalize gradients.
     grads = tf.math.l2_normalize(grads)
     # image_var += 10.0 * grads # 10.0 is learning_rate
-    optimizer.apply_gradients(zip(grads * -1, image_var))    # For SGD, w = w - learning_rate * g
+    optimizer.apply_gradients(zip(grads * -1, image_var))  # For SGD, w = w - learning_rate * g
     return loss, image_var
 
 
@@ -30,8 +30,8 @@ def __initialize_image__(img_width, img_height, rescale_mode="tf", value_range=0
 
 def __deprocess_image__(img, crop_border=0.1):
     # Normalize array: center on 0., ensure variance is 0.15
-    img -= img.mean()
-    img /= img.std() + 1e-5
+    img -= img.mean(axis=(0, 1))
+    img /= img.std(axis=(0, 1)) + 1e-5
     img *= 0.15
 
     # Center crop
@@ -61,7 +61,20 @@ def __get_cols_rows__(total, rows=-1):
     return cols, rows
 
 
-def stack_and_plot_images(images, margin=5, margin_value=0, rows=-1, ax=None, base_size=3):
+def put_text_on_image(image, text, coord=(5, 5), color=(255, 0, 0)):
+    from PIL import Image
+    from PIL import ImageDraw
+
+    # from PIL import ImageFont
+
+    image = image * 255 if image.max() < 2 else image
+    img = Image.fromarray(image.astype("uint8"))
+    draw = ImageDraw.Draw(img)
+    draw.text(coord, str(text), color)
+    return np.array(img)
+
+
+def stack_and_plot_images(images, texts=None, margin=5, margin_value=0, rows=-1, ax=None, base_size=3):
     """ Stack and plot a list of images. Returns ax, stacked_images """
     import matplotlib.pyplot as plt
 
@@ -69,6 +82,10 @@ def stack_and_plot_images(images, margin=5, margin_value=0, rows=-1, ax=None, ba
     images = images[: rows * cols]
     # print(">>>> rows:", rows, ", cols:", cols, ", total:", len(images))
 
+    if texts is not None:
+        images = [put_text_on_image(imm, itt) for imm, itt in zip(images, texts)] + list(images[len(texts) :])
+        images = np.array(images)
+
     if ax is None:
         _, ax = plt.subplots(1, 1, figsize=(base_size * cols, base_size * rows))
 
@@ -89,6 +106,7 @@ def stack_and_plot_images(images, margin=5, margin_value=0, rows=-1, ax=None, ba
     ax.set_axis_off()
     ax.grid(False)
     plt.tight_layout()
+    plt.show()
     return ax, stacked_images
 
 
@@ -97,14 +115,14 @@ def visualize_filters(
     layer_name="auto",
     filter_index_list=[0],
     input_shape=None,
-    rescale_mode="tf",
+    rescale_mode="auto",
     iterations=30,
-    optimizer="SGD",    # "SGD" / "RMSprop" / "Adam"
+    optimizer="SGD",  # "SGD" / "RMSprop" / "Adam"
     learning_rate="auto",
     value_range=0.125,
-    random_magnitude=1.0, # basic random value for `tf.roll` and `random_rotation` is `4` and `1`.
+    random_magnitude=1.0,  # basic random value for `tf.roll` and `random_rotation` is `4` and `1`.
     crop_border=0.1,
-    base_size=3
+    base_size=3,
 ):
     from tensorflow.keras.preprocessing.image import random_rotation
 
@@ -131,6 +149,10 @@ def visualize_filters(
         elif optimizer == "sgd":
             optimizer = tf.optimizers.SGD(learning_rate)
 
+    if rescale_mode.lower() == "auto":
+        rescale_mode = getattr(model, "rescale_mode", "torch")
+        print(">>>> rescale_mode:", rescale_mode)
+
     # We run gradient ascent for [iterations] steps
     losses, filter_images = [], []
     for filter_index in filter_index_list:
@@ -210,10 +232,14 @@ def make_gradcam_heatmap(model, processed_image, layer_name="auto", pred_index=N
     return heatmap.numpy().astype("float32"), preds.numpy()
 
 
-def make_and_apply_gradcam_heatmap(model, image, layer_name="auto", rescale_mode="tf", pred_index=None, alpha=0.8, use_v2=True, plot=True):
+def make_and_apply_gradcam_heatmap(model, image, layer_name="auto", rescale_mode="auto", pred_index=None, alpha=0.8, use_v2=True, plot=True):
     import matplotlib.cm as cm
     import matplotlib.pyplot as plt
 
+    if rescale_mode.lower() == "auto":
+        rescale_mode = getattr(model, "rescale_mode", "torch")
+        print(">>>> rescale_mode:", rescale_mode)
+
     image = np.array(image)
     image = image * 255 if image.max() < 2 else image  # Makse sure it's [0, 255]
     processed_image = tf.expand_dims(tf.image.resize(image, model.input_shape[1:-1]), 0)
@@ -236,12 +262,13 @@ def make_and_apply_gradcam_heatmap(model, image, layer_name="auto", rescale_mode
     if model.output_shape[-1] == 1000:
         decode_pred = tf.keras.applications.imagenet_utils.decode_predictions(preds, top=5)[0]
         top_5_idxes = np.argsort(preds[0])[-5:][::-1]
-        print(">>>> Top5 predictions:", [[ii, *jj] for ii, jj in zip(top_5_idxes, decode_pred)])
+        print(">>>> Top5 predictions:", np.array([[ii, *jj] for ii, jj in zip(top_5_idxes, decode_pred)]))
     if plot:
         fig = plt.figure()
         plt.imshow(superimposed_img)
         plt.axis("off")
         plt.tight_layout()
+        plt.show()
     return superimposed_img, heatmap, preds
 
 
@@ -293,7 +320,7 @@ def down_sample_matrix_axis_0(dd, target, method="avg"):
     return dd
 
 
-def plot_attention_score_maps(model, image, rescale_mode="tf", attn_type="auto", rows=-1, base_size=3):
+def plot_attention_score_maps(model, image, rescale_mode="auto", attn_type="auto", rows=-1, base_size=3):
     import matplotlib.pyplot as plt
 
     if isinstance(model, tf.keras.models.Model):
@@ -314,6 +341,10 @@ def plot_attention_score_maps(model, image, rescale_mode="tf", attn_type="auto",
         layer_name_title = ""
         assert attn_type != "auto"
 
+    if rescale_mode.lower() == "auto":
+        rescale_mode = getattr(model, "rescale_mode", "torch")
+        print(">>>> rescale_mode:", rescale_mode)
+
     attn_type = attn_type.lower()
     check_type_is = lambda tt: (tt in model.name.lower()) if attn_type == "auto" else (attn_type.startswith(tt))
     if check_type_is("beit"):
@@ -344,6 +375,15 @@ def plot_attention_score_maps(model, image, rescale_mode="tf", attn_type="auto",
         cum_mask = [mask[0]] + [down_sample_matrix_axis_0(mask[ii], mask[ii - 1].shape[1], "max") for ii in range(1, len(mask))]
         cum_mask = [matmul_prod(cum_mask[: ii + 1]).mean(0) for ii in range(len(cum_mask))]
         mask = [ii.mean(0) for ii in mask]
+    elif check_type_is("coat"):
+        # coat attn_score [batch, num_heads, cls_token + hh * ww, key_dim]
+        print(">>>> Attention type: coat")
+        mask = [np.array(ii)[0].mean((0))[1:] for ii in attn_scores if len(ii.shape) == 4][::-1]
+        mask = [ii.max(-1, keepdims=True) for ii in mask]
+        target_shape = np.min([ii.shape[0] for ii in mask])
+        cum_mask = [down_sample_matrix_axis_0(mask[ii], target_shape, "max") for ii in range(len(mask))]
+        cum_mask = [ii[:, 0] for ii in cum_mask]
+        mask = [ii[:, 0] for ii in mask]
     elif check_type_is("halo"):
         # halo attn_score [batch, num_heads, hh, ww, query_block * query_block, kv_kernel * kv_kernel]
         print(">>>> Attention type: halo")
